@@ -21,7 +21,7 @@ template <class S, class T> inline void clone(T*& dst, S* src, int n)
 	dst = new T[n];
 	memcpy((void *)dst,(void *)src,sizeof(T)*n);
 }
-#define INF HUGE_VAL
+#define INF DBL_MAX
 #define Malloc(type,n) (type *)malloc((n)*sizeof(type))
 
 
